==> PyJabber.0.2.tar.gz: testclient.py <==
#! /usr/bin/env python

#   testclient: simple test program
#   Copyright (C) 1999  Daniel Arbuckle
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#    
#    Daniel Arbuckle can be contacted by email at djarb@wvc-omak.ctc.edu

# THIS IS AN UGLY PROGRAM
# But it does illustrate the basics of sending and recieving through a Jabber
# stream via PyJabber

import Jabber
import JabberPackets
import FileSocket
import sys

try:
    import readline
except:
    pass


q = Jabber.PacketQueue("jabber.org")
#q.set_debug(FileSocket.FileSocket(sys.stdout))

def handle_packet():
    p = q.get()
    if isinstance(p, JabberPackets.Message):
        print "got message of type", p.get_type()
        print "from:", p.get_from() or "anonymous"
        if p.get_error(): print p.get_error()[1]
        print p.get_body_text()
        print "> ",
        sys.stdout.flush()
    elif isinstance(p, JabberPackets.Presence):
        print "got presence of type", p.get_type()
        print "from:", p.get_from() or "anonymous"
        print p.get_status()
        print "> ",
        sys.stdout.flush()
    elif isinstance(p, JabberPackets.IQ):
        print "got iq of type", p.get_type()
        print "from:", p.get_from() or "anonymous"
        if p.get_error(): print p.get_error()[1]
        print "> ",
        sys.stdout.flush()
        
q.set_callback(handle_packet)

cmd = raw_input("> ")

while cmd != "quit":
    if cmd == "login":
        s = JabberPackets.IQ()
        u = raw_input("Username: ")
        p = raw_input("Password: ")
        r = raw_input("Resource: ")
        s.add_set("jabber:iq:auth", username=u, password=p, resource=r)
        q.put(s)
    elif cmd == "presence":
        s = JabberPackets.Presence();
        t = raw_input("type: ")
        p = int(raw_input("priority: "))
        if t and t != "available": s.set_type(t)
        s.set_priority(p)
        q.put(s)
    elif cmd == "message":
        s = JabberPackets.Message()
        to = raw_input("to: ")
        subj = raw_input("subject: ")
        msg = ""
        line = raw_input()
        while line != ".":
            msg = msg + "\n" + line
            line = raw_input()
        s.set_to(to)
        s.set_subject(subj)
        s.set_body_text(msg)
        q.put(s)
    elif cmd == "register":
        s = JabberPackets.IQ()
        u = raw_input("Username: ")
        p = raw_input("Password: ")
        n = raw_input("Name: ")
        e = raw_input("Email: ")
        s.add_set("jabber:iq:register", username=u, password=p, name=n, email=e)
        q.put(s)
    cmd = raw_input("> ")

==> PyJabber.0.3.tar.gz: testclient.py <==
#! /usr/bin/env python

#   testclient: simple test program
#   Copyright (C) 1999  Daniel Arbuckle
#
#   This program is free software; you can redistribute it and/or modify
#   it under the terms of the GNU General Public License as published by
#   the Free Software Foundation; either version 2 of the License, or
#   (at your option) any later version.
#
#   This program is distributed in the hope that it will be useful,
#   but WITHOUT ANY WARRANTY; without even the implied warranty of
#   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#   GNU General Public License for more details.
#
#    You should have received a copy of the GNU General Public License
#    along with this program; if not, write to the Free Software
#    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#    
#    Daniel Arbuckle can be contacted by email at djarb@wvc-omak.ctc.edu

# THIS IS AN UGLY PROGRAM
# But it does illustrate the basics of sending and recieving through a Jabber
# stream via PyJabber

import Jabber
import JabberPackets
import FileSocket
import sys

try:
    import readline
except:
    pass


q = Jabber.SimpleClient("jabber.org")
#q = Jabber.SimpleClient("jabber.org",
#                        out_debug = FileSocket.FileSocket(sys.stdout))

def handle_packet():
    p = q.get()
    if isinstance(p, JabberPackets.Message):
        print "got message of type", p.get_type()
        print "from:", p.get_from() or "anonymous"
        if p.get_error(): print p.get_error()[1]
        print p.get_body_text()
        print "> ",
        sys.stdout.flush()
    elif isinstance(p, JabberPackets.Presence):
        print "got presence of type", p.get_type()
        print "from:", p.get_from() or "anonymous"
        print p.get_status()
        print "> ",
        sys.stdout.flush()
    elif isinstance(p, JabberPackets.IQ):
        print "got iq of type", p.get_type()
        print "from:", p.get_from() or "anonymous"
        if p.get_error(): print p.get_error()[1]
        print "> ",
        sys.stdout.flush()
        
q.set_callback(handle_packet)

cmd = raw_input("> ")

while cmd != "quit":
    if cmd == "login":
        s = JabberPackets.IQ()
        u = raw_input("Username: ")
        p = raw_input("Password: ")
        r = raw_input("Resource: ")
        s.add_set("jabber:iq:auth", username=u, password=p, resource=r)
        q.put(s)
    elif cmd == "presence":
        s = JabberPackets.Presence();
        t = raw_input("type: ")
        p = int(raw_input("priority: "))
        if t and t != "available": s.set_type(t)
        s.set_priority(p)
        q.put(s)
    elif cmd == "message":
        s = JabberPackets.Message()
        to = raw_input("to: ")
        subj = raw_input("subject: ")
        msg = ""
        line = raw_input()
        while line != ".":
            msg = msg + "\n" + line
            line = raw_input()
        s.set_to(to)
        s.set_subject(subj)
        s.set_body_text(msg)
        q.put(s)
    elif cmd == "register":
        s = JabberPackets.IQ()
        u = raw_input("Username: ")
        p = raw_input("Password: ")
        n = raw_input("Name: ")
        e = raw_input("Email: ")
        s.add_set("jabber:iq:register", username=u, password=p, name=n, email=e)
        q.put(s)
    cmd = raw_input("> ")
